@@ -1,38 +1,38 @@
 #  --------------------------------------------------------------------------
 
-mongrad <- function(x, Wfd, basislist=vector("list",JMAX)) {
-#  Evaluates the gradient with respect to the coefficients in Wfd
+mongrad <- function(x, Wfdobj, basislist=vector("list",JMAX)) {
+#  Evaluates the gradient with respect to the coefficients in Wfdobj
 #     of a monotone function of the form
-#            h(x) = [D^{-1} exp Wfd](x)
+#            h(x) = [D^{-1} exp Wfdobj](x)
 #  where  D^{-1} means taking the indefinite integral.
 #  The interval over which the integration takes places is defined in
-#  the basisfd object in Wfd.
+#  the basisfd object in Wfdobj.
 #  Arguments:
 #  X      ... argument values at which function and derivatives are evaluated
-#  Wfd    ... a functional data object
+#  WFDOBJ ... a functional data object
 #  BASISLIST ... a list containing values of basis functions
 #  Returns:
 #  GVAL   ... value of gradient at input values in X.
 
-#  Last modified 15 December 2005
+#  Last modified 21 October 2008 by Jim Ramsay
 
   JMAX <- 15
   JMIN <- 11
   EPS  <- 1E-5
 
-  coef  <- Wfd$coefs
+  coef  <- Wfdobj$coefs
   coefd <- dim(coef)
   ndim  <- length(coefd)
-  if (ndim > 1 && coefd[2] != 1) stop("Wfd is not a single function")
+  if (ndim > 1 && coefd[2] != 1) stop("Wfdobj is not a single function")
 
-  basisfd  <- Wfd$basis
+  basisfd  <- Wfdobj$basis
   rangeval <- basisfd$rangeval
   nbasis   <- basisfd$nbasis
   onebas   <- rep(1,nbasis)
+  width    <- rangeval[2] - rangeval[1]
 
   #  set up first iteration
 
-  width <- rangeval[2] - rangeval[1]
   JMAXP <- JMAX + 1
   h <- rep(1,JMAXP)
   h[2] <- 0.25
@@ -57,27 +57,27 @@ mongrad <- function(x, Wfd, basislist=vector("list",JMAX)) {
   tnm <- 0.5
 
   #  now iterate to convergence
-  for (j in 2:JMAX) {
+  for (iter in 2:JMAX) {
     tnm  <- tnm*2
     del  <- width/tnm
     tj   <- seq(rangeval[1]+del/2, rangeval[2]-del/2, del)
     tval <- c(tval, tj)
-    if (is.null(basislist[[j]])) {
+    if (is.null(basislist[[iter]])) {
         bmat <- getbasismatrix(tj, basisfd)
-        basislist[[j]] <- bmat
+        basislist[[iter]] <- bmat
     } else {
-        bmat <- basislist[[j]]
+        bmat <- basislist[[iter]]
     }
     fx   <- exp(bmat %*% coef)
     gval <- outer(c(fx),onebas)*bmat
     fval <- rbind(fval,gval)
-    smat[j,] <- (smat[j-1,] + width*apply(fval,2,sum)/tnm)/2
-    if (j >= max(c(5,JMIN))) {
-      ind <- (j-4):j
+    smat[iter,] <- (smat[iter-1,] + width*apply(fval,2,sum)/tnm)/2
+    if (iter >= max(c(5,JMIN))) {
+      ind <- (iter-4):iter
       result <- polintmat(h[ind],smat[ind,],0)
       ss  <- result[[1]]
       dss <- result[[2]]
-      if (all(abs(dss) < EPS*max(abs(ss))) || j == JMAX) {
+      if (all(abs(dss) < EPS*max(abs(ss))) || iter >= JMAX) {
         # successful convergence
         # sort argument values and corresponding function values
         ordind <- order(tval)
@@ -92,8 +92,7 @@ mongrad <- function(x, Wfd, basislist=vector("list",JMAX)) {
         return(gval)
       }
     }
-    smat[j+1,] <- smat[j,]
-    h[j+1]     <- 0.25*h[j]
+    smat[iter+1,] <- smat[iter,]
+    h[iter+1]     <- 0.25*h[iter]
   }
-  #stop(paste("No convergence after",JMAX," steps in MONGRAD"))
 }
